@@ -55,7 +55,7 @@
 
 ;;}}}
 ;;{{{ Customizations:
-;;;###autoload
+
 (defcustom dectalk-default-speech-rate 225
   "*Default speech rate at which TTS is started. "
   :group 'tts
@@ -77,7 +77,7 @@
   (dtk-initialize))
 
 ;;;### autoload
-(defalias 'dtk-exp 'dectalk)
+
 
 ;;}}}
 ;;{{{ Forward declarations:
@@ -664,7 +664,6 @@ and TABLE gives the values along that dimension."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
