@@ -104,7 +104,6 @@ Particularly useful for web browsing."
   :group 'tts)
 (make-variable-buffer-local 'tts-strip-octals)
 
-
 (defcustom dtk-speech-rate-base
   (if (string-match "dtk" dtk-program) 180 50)
   "*Value of lowest tolerable speech rate."
@@ -246,18 +245,41 @@ has higher precedence than `face'."
   "Applies pronunciations specified in pronunciation table to current buffer.
 Modifies text and point in buffer."
   (cl-declare (special emacspeak-pronounce-pronunciation-personality))
-  (let ((words
-         (cl-loop for k being the hash-keys of pronunciation-table collect k)))
-    (cl-loop
-     for w in words do
-     (when w
-       (let ((pronunciation (gethash w pronunciation-table))
-             (pp nil))
-         (goto-char (point-min))
-         (cond
-          ((stringp pronunciation)
-           (while (search-forward w nil t)
+  (cl-loop
+   for w in
+   (cl-loop for k being the hash-keys of pronunciation-table collect k)
+   do
+   (when w
+     (let ((pronunciation (gethash w pronunciation-table))
+           (pp nil))
+       (goto-char (point-min))
+       (cond
+        ((stringp pronunciation)
+         (while (search-forward w nil t)
+           (setq pp (dtk-get-style))
+           (replace-match pronunciation t t)
+           (when (or pp emacspeak-pronounce-pronunciation-personality)
+             (put-text-property
+              (match-beginning 0)
+              (+ (match-beginning 0) (length pronunciation))
+              'personality
+              (cond
+               ((and emacspeak-pronounce-pronunciation-personality
+                     (listp pp))
+                (nconc pp
+                       (list emacspeak-pronounce-pronunciation-personality)))
+               (t pp))))))
+        ((consp pronunciation)
+         (let ((matcher (car pronunciation))
+               (pronouncer (cdr pronunciation))
+               (pronunciation ""))
+           (while (funcall matcher w nil t)
              (setq pp (dtk-get-style))
+             (setq pronunciation
+                   (save-match-data
+                     (funcall
+                      pronouncer
+                      (buffer-substring (match-beginning 0) (match-end 0)))))
              (replace-match pronunciation t t)
              (when (or pp emacspeak-pronounce-pronunciation-personality)
                (put-text-property
@@ -269,32 +291,8 @@ Modifies text and point in buffer."
                        (listp pp))
                   (nconc pp
                          (list emacspeak-pronounce-pronunciation-personality)))
-                 (t pp))))))
-          ((consp pronunciation)
-           (let ((matcher (car pronunciation))
-                 (pronouncer (cdr pronunciation))
-                 (pronunciation ""))
-             (while (funcall matcher w nil t)
-               (setq pp (dtk-get-style))
-               (setq pronunciation
-                     (save-match-data
-                       (funcall pronouncer
-                                (buffer-substring
-                                 (match-beginning 0)
-                                 (match-end 0)))))
-               (replace-match pronunciation t t)
-               (when (or pp emacspeak-pronounce-pronunciation-personality)
-                 (put-text-property
-                  (match-beginning 0)
-                  (+ (match-beginning 0) (length pronunciation))
-                  'personality
-                  (cond
-                   ((and emacspeak-pronounce-pronunciation-personality
-                         (listp pp))
-                    (nconc pp
-                           (list emacspeak-pronounce-pronunciation-personality)))
-                   (t pp)))))))
-          (t nil)))))))
+                 (t pp)))))))
+        (t nil))))))
 
 ;;}}}
 ;;{{{  Helpers to handle invisible text:
@@ -343,7 +341,6 @@ Optional argument FORCE  flushes the command to the speech server."
       (dtk-interp-silence duration
                           (if force "\nd" "")))))
 
-
 (defcustom dtk-use-tones t
   "Allow tones to be turned off."
   :type 'boolean
@@ -475,7 +472,6 @@ specifies the current pronunciation mode --- See
       (while (re-search-forward dtk-bracket-regexp nil t)
         (replace-match " " nil t))))))
 
-
 (defcustom dtk-speak-nonprinting-chars nil
   "*Option that specifies handling of non-printing chars.
 Non nil value means non printing characters  should be
@@ -532,10 +528,10 @@ Argument MODE  specifies the current pronunciation mode."
       (setq personality (dtk-get-style (match-beginning 0)))
       (setq replacement
             (if (eq 'all mode)
-                (format " aw %s %s"
-                        (/ (- (match-end 0) (match-beginning 0)) len)
-                        (if (string-equal " " pattern)
-                            " space " string))
+                (format
+                 " aw %s %s"
+                 (/ (- (match-end 0) (match-beginning 0)) len)
+                 (if (string-equal " " string) " space " string))
               ""))
       (replace-match replacement nil t)
       (setq start (- (point) (length replacement)))
@@ -757,7 +753,7 @@ Arguments START and END specify region to speak."
           (dtk-interp-silence (get-text-property start 'pause) nil)))))))
 
 ;;;Force the speech.
-(defalias 'dtk-force 'dtk-interp-speak)
+(cl--defalias 'dtk-force 'dtk-interp-speak)
 
 ;;;Write out the string to the tts via TCL.
 ;;; No quoting is done,
@@ -809,10 +805,8 @@ will say ``aw fifteen dot'' when speaking the string
           (delete
            (read-from-minibuffer "Specify repeating pattern to delete: ")
            dtk-cleanup-repeats)))
-   (t (setq dtk-cleanup-repeats
-            (cons
-             (read-from-minibuffer "Specify repeating pattern: ")
-             dtk-cleanup-repeats)))))
+   (t 
+    (cl-pushnew (read-from-minibuffer "Specify repeating pattern: ") dtk-cleanup-repeats))))
 
 ;;}}}
 ;;{{{  Controlling how we produce  output
@@ -1521,7 +1515,7 @@ available TTS servers.")
 ;;{{{  interactively selecting the server:
 
 ;;; will be reset on a per TTS engine basis.
-(defalias 'tts-get-voice-command 'dectalk-get-voice-command)
+(fset 'tts-get-voice-command 'dectalk-get-voice-command)
 
 (defun tts-voice-reset-code ()
   "Return voice reset code."
@@ -1645,7 +1639,6 @@ Optional interactive prefix arg restarts current TTS server."
 (defvar dtk-local-server-process nil
   "Local server process.")
 
-
 (defvar dtk-speech-server-program "speech-server"
   "Local speech server script.")
 (defvar dtk-local-server-port "2222"
@@ -1862,10 +1855,10 @@ only speak upto the first ctrl-m."
         (dtk-interp-sync)
         (insert text)
         (dtk--delete-invisible-text)
+        (dtk-handle-repeating-patterns mode)
         (when pronunciation-table
           (tts-apply-pronunciations pronunciation-table))
         (dtk-unicode-replace-chars mode)
-        (dtk-handle-repeating-patterns mode)
         (dtk-quote mode)
         (goto-char (point-min))
         (skip-syntax-forward " ")       ;skip leading whitespace
@@ -1944,12 +1937,13 @@ inserted.  Otherwise it is a number that specifies grouping"
            (setq count 1)
            (pop group)
            (if p
-               (insert (propertize "," 'personality p))
+               (insert (propertize ", " 'personality p))
              (insert ", ")))
           (t (cl-incf count)
              (insert " ")))))
       (setq contents (buffer-string)))
-    (tts-with-punctuations 'some (dtk-speak contents))))
+    (tts-with-punctuations 'some (dtk-speak contents))
+    t))
 
 (defun dtk-letter (letter)
   "Speak a LETTER."
@@ -2102,7 +2096,6 @@ Notification is logged in the notifications buffer unless `dont-log' is T. "
 ;;; local variables:
 ;;; coding: utf-8
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
