@@ -77,7 +77,11 @@
 (require 'emacspeak-speak)
 (require 'emacspeak-sounds)
 (require 'ansi-color)
-(eval-when-compile (require 'which-func))
+(require 'which-func)
+(require 'vc)
+(require 'hippie-exp)
+(require 'comint)
+(require 'shell)
 ;;}}}
 ;;{{{ Forward Declarations:
 (defvar emacspeak-prefix)
@@ -85,7 +89,7 @@
 ;;}}}
 ;;{{{ Silence advice chatter:
 
-(defadvice ad--defalias-fset (around emacspeak pre act comp)
+(defadvice ad--cl--defalias-fset (around emacspeak pre act comp)
   "Silence chatter."
   (ems-with-messages-silenced ad-do-it))
 
@@ -550,14 +554,20 @@ the words that were capitalized."
 
 ;;; Large deletions also produce auditory icons if possible
 
-(defadvice kill-line (before emacspeak pre act comp)
-  "Speak line before killing it. "
-  (when (ems-interactive-p)
+(cl-loop
+ for f in 
+ '(kill-line kill-whole-line)
+ do
+ (eval
+  `(defadvice ,f (before emacspeak pre act comp)
+     "Speak line before killing it. "
+     (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (when dtk-stop-immediately (dtk-stop))
     (let ((dtk-stop-immediately nil))
       (dtk-tone-deletion)
-      (emacspeak-speak-line 1))))
+      (emacspeak-speak-line 1))))))
+
 
 (defadvice kill-sexp (before emacspeak pre act comp)
   "Speak the sexp you killed."
@@ -601,7 +611,6 @@ the words that were capitalized."
 ;;}}}
 ;;{{{ advice tabify:
 
-
 (defcustom emacspeak-untabify-fixes-non-breaking-space t
   "Advice untabify to change non-breaking space chars to space."
   :type 'boolean
@@ -684,6 +693,22 @@ see option emacspeak-untabify-fixes-non-breaking-space."
     (tts-with-punctuations 'all
                            (dtk-speak (ad-get-arg 0)))))
 
+(defadvice read-multiple-choice (before emacspeak pre act comp)
+  "Provide auditory feedback."
+  (let ((dtk-stop-immediately  nil)
+        (msg (ad-get-arg 0))
+        (choices 
+         (mapcar
+          #'(lambda (c)
+              (format "%c: %s"
+                      (cl-first c) (cl-second c)))
+          (ad-get-arg 1))))
+    (emacspeak-auditory-icon 'open-object)
+    (dtk-speak msg)
+    (sox-tones 2 2)
+    (dtk-speak-list choices)))
+
+
 (cl-loop
  for f in
  '(
@@ -697,7 +722,7 @@ see option emacspeak-untabify-fixes-non-breaking-space."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'select-object)
        (tts-with-punctuations 'all
-                              (emacspeak-speak-current-field))))))
+         (emacspeak-speak-current-field))))))
 
 (defvar emacspeak-last-message nil
   "Holds the last output generated by the Emacs 'message function.")
@@ -728,12 +753,18 @@ icon."
 (defadvice progress-reporter-do-update (around emacspeak pre act comp)
   "Silence progress reporters for now."
   (ems-with-messages-silenced ad-do-it)
-  (when emacspeak-advice-progress-reporter
+  (when (and ad-return-value emacspeak-advice-progress-reporter)
     (emacspeak-auditory-icon 'progress)))
 
+
+(defadvice progress-reporter-done (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (emacspeak-auditory-icon 'time))
+
 (defvar inhibit-message)
 (cl-loop
- for f in '(minibuffer-message message display-message-or-buffer) do
+ for f in '(minibuffer-message set-minibuffer-message
+            message display-message-or-buffer) do
  (eval
   `(defadvice ,f (around emacspeak pre act comp)
      "Speak the message."
@@ -742,7 +773,11 @@ icon."
      (let ((inhibit-read-only t)
            (m nil))
        ad-do-it
-       (setq m (current-message))
+       (setq m
+             (or 
+              (current-message)
+              (if (bound-and-true-p minibuffer-message-overlay)
+                  (overlay-get minibuffer-message-overlay 'after-string))))
        (when
            (and
             (null inhibit-message)
@@ -820,13 +855,11 @@ icon."
 
 ;;{{{ advising signal
 
-
 (defcustom emacspeak-speak-errors t
   "Specifies if error messages are cued."
   :type 'boolean
   :group 'emacspeak-speak)
 
-
 (defvar emacspeak-speak-signals t
   "Specifies if signalled messages are cued.")
 
@@ -1726,7 +1759,7 @@ Produce an auditory icon if possible."
     (emacspeak-speak-mode-line)))
 (cl-loop
  for f in
- '(kill-buffer quit-window)
+ '(kill-buffer kill-current-buffer quit-window)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -3003,7 +3036,6 @@ Produce auditory icons if possible."
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
-
 ;;}}}
 ;;{{{find-library:
 
@@ -3029,19 +3061,28 @@ Produce auditory icons if possible."
     (setq lv-emacspeak-cache (buffer-substring (point-min) (point-max)))
     (emacspeak-speak-buffer)))
 
-
 (defadvice lv-delete-window (after emacspeak pre act comp)
   "Provide auditory feedback."
   (dtk-stop)
   (emacspeak-auditory-icon 'delete-object))
 
+;;}}}
+;;{{{log-edit-done
+
+(defadvice log-edit-done (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p)
+    (emacspeak-speak-mode-line)
+    (emacspeak-auditory-icon 'close-object)
+    ))
+
+
 ;;}}}
 (provide 'emacspeak-advice)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
