@@ -199,7 +199,8 @@ Date defaults to today."
 ;;}}}
 ;;{{{ Stream using get_iplayer:
 
-(defvar emacspeak-bbc-iplayer-handle "/tmp/iplayer-stream.mp3"
+(defvar emacspeak-bbc-iplayer-handle
+  (expand-file-name  "iplayer-stream.mp3" temporary-file-directory)
   "Location of named pipe used for streaming.")
 
 (defcustom emacspeak-bbc-get-iplayer (executable-find "get_iplayer")
@@ -239,7 +240,6 @@ Date defaults to today."
     (sit-for 1)
     (emacspeak-m-player emacspeak-bbc-iplayer-handle)))
 
-
 (defun emacspeak-bbc-get-iplayer-stream-pid (pid)
   "Stream using get_iplayer."
   (interactive "sPid ")
@@ -261,7 +261,7 @@ Date defaults to today."
 
 (defun emacspeak-bbc-chrome-action (button)
   "Play program  refered to by this button."
-  (browse-url-chromium (button-get  button 'link)))
+  (browse-url-chrome (button-get  button 'link)))
 
 ;;}}}
 ;;{{{ Generic Button Action:
@@ -382,7 +382,6 @@ Interactive prefix arg filters  content by genre."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
