@@ -142,15 +142,6 @@ This is used by the various Bookshare view commands to display
 ;;}}}
 ;;{{{ Variables:
 
-(defvar emacspeak-bookshare-curl-program (executable-find "curl")
-  "Curl executable.")
-
-(defvar emacspeak-bookshare-curl-common-options
-  " --insecure --location "
-  "Common Curl options for Bookshare. Includes --insecure as per
-Bookshare docs."
-  )
-
 (defvar emacspeak-bookshare-api-base
   "https://api.bookshare.org"
   "Base end-point for Bookshare API  access.")
@@ -292,6 +283,10 @@ Argument id specifies content. Argument fmt = 0 for Braille, 1
 
 (defvar emacspeak-bookshare-last-action-uri nil
   "Cache last API call URI.")
+(defvar emacspeak-bookshare-curl-common-options
+  " --insecure --location "
+  "Common Curl options for Bookshare. Includes --insecure as per
+Bookshare docs.")
 
 (defun emacspeak-bookshare-api-call (operation operand &optional no-auth)
   "Make a Bookshare API  call and get the result.
@@ -302,7 +297,7 @@ Optional argument 'no-auth says we dont need a user auth."
   (emacspeak-bookshare-get-result
    (format
     "%s %s %s  %s 2>/dev/null"
-    emacspeak-bookshare-curl-program
+    emacspeak-curl-program
     emacspeak-bookshare-curl-common-options
     (if no-auth "" (emacspeak-bookshare-user-password))
     emacspeak-bookshare-last-action-uri)))
@@ -315,7 +310,7 @@ Optional argument 'no-auth says we dont need a user auth."
         (emacspeak-bookshare-page-rest-endpoint))
   (emacspeak-bookshare-get-result
    (format "%s %s %s  %s 2>/dev/null"
-           emacspeak-bookshare-curl-program
+           emacspeak-curl-program
            emacspeak-bookshare-curl-common-options
            (emacspeak-bookshare-user-password)
            emacspeak-bookshare-last-action-uri)))
@@ -513,7 +508,7 @@ Optional interactive prefix arg prompts for a category to use as a filter."
   (shell-command
    (format
     "%s %s %s  '%s' -o \"%s\""
-    emacspeak-bookshare-curl-program
+    emacspeak-curl-program
     emacspeak-bookshare-curl-common-options
     (emacspeak-bookshare-user-password)
     url
@@ -684,8 +679,8 @@ b Browse
     (error "Does not look like a Bookshare response."))
   (mapc #'emacspeak-bookshare-apply-handler (dom-children response)))
 
-(defalias 'emacspeak-bookshare-version-handler 'ignore)
-(defalias 'emacspeak-bookshare-debugInfo-handler 'ignore)
+(cl--defalias 'emacspeak-bookshare-version-handler 'ignore)
+(cl--defalias 'emacspeak-bookshare-debugInfo-handler 'ignore)
 
 (defun emacspeak-bookshare-recurse (tree)
   "Recurse down tree."
@@ -1117,7 +1112,6 @@ Target location is generated from author and title."
                 'auditory-icon 'item))
     (message "Unpacked content.")))
 
-
 (defcustom emacspeak-bookshare-xslt
   "daisyTransform.xsl"
   "Name of bookshare  XSL transform."
@@ -1357,7 +1351,6 @@ Useful for fulltext search in a book."
     (error "Your Emacs doesn't have EWW."))
   (let ((gc-cons-threshold (max 8000000 gc-cons-threshold))
         (xsl (emacspeak-bookshare-xslt directory))
-          (locals (locate-dominating-file directory emacspeak-speak-directory-settings))
         (buffer (get-buffer-create "Full Text"))
         (command nil)
         (inhibit-read-only t))
@@ -1371,13 +1364,11 @@ Useful for fulltext search in a book."
       (erase-buffer)
       (setq buffer-undo-list t)
       (shell-command command (current-buffer) nil)
-      (when locals 
-      (setq locals (expand-file-name  emacspeak-speak-directory-settings locals)))
       (add-hook
        'emacspeak-web-post-process-hook
        #'(lambda nil
            (setq emacspeak-bookshare-this-book directory)
-           (when (and locals (file-exists-p locals))(load locals))
+           (emacspeak-speak-load-directory-settings directory)
            (emacspeak-auditory-icon 'open-object)
            (emacspeak-speak-mode-line)))
       (browse-url-of-buffer)
@@ -1417,7 +1408,6 @@ Useful for fulltext search in a book."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
