@@ -215,7 +215,7 @@ in a non eterm buffer if executed via C-e C-e"
    ((or (eq major-mode 'term-mode)
         (eq major-mode 'tshell-mode))
     (term-send-raw))
-   ((= last-input-event 5) (end-of-line))
+   ((= last-input-event 5) (call-interactively #'end-of-line))
    (t (beep))))
 
 (defun emacspeak-eterm-speak-cursor ()
@@ -1355,7 +1355,6 @@ emacspeak-eterm-remote-hostnames")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
