@@ -409,6 +409,12 @@
 (require 'emacspeak-webutils)
 (require 'emacspeak-google)
 
+;;}}}
+;;{{{defgroup:
+(defgroup emacspeak-eww nil
+  "EWW Customizations"
+  :group 'emacspeak)
+
 ;;}}}
 ;;{{{ Helpers:
 ;;; Generate functions emacspeak-eww-current-title and friends:
@@ -550,11 +556,15 @@ are available are cued by an auditory icon on the header line."
    (emacspeak-eww-masquerade
     (setq ad-return-value emacspeak-eww-masquerade-as))
    (t (setq ad-return-value "User-Agent: URL/Emacs \r\n"))))
+(defcustom emacspeak-eww-inhibit-images nil
+  "Turn this on to avoid rendering images."
+  :type 'boolean
+  :group 'emacspeak-eww)
 
 (defun emacspeak-eww-setup ()
   "Setup keymaps etc."
   (cl-declare (special eww-mode-map eww-link-keymap
-                       shr-inhibit-images
+                       shr-inhibit-images emacspeak-eww-inhibit-images
                        emacspeak-pronounce-common-xml-namespace-uri-pronunciations
                        emacspeak-eww-masquerade
                        emacspeak-pronounce-load-pronunciations-on-startup))
@@ -565,8 +575,8 @@ are available are cued by an auditory icon on the header line."
      'eww-mode
      emacspeak-speak-rfc-3339-datetime-pattern
      (cons 're-search-forward 'emacspeak-speak-decode-rfc-3339-datetime)))
-;;; turn off images
-  (setq shr-inhibit-images t)
+;;; turn off images on request 
+  (setq shr-inhibit-images emacspeak-eww-inhibit-images)
 ;;; remove "I" "o" from eww-link-keymap
   (cl-loop
    for c in
@@ -602,6 +612,9 @@ are available are cued by an auditory icon on the header line."
      ("C" eww-view-dom-having-class)
      ("C-e" emacspeak-prefix-command)
      ("C-t" emacspeak-eww-transcode)
+     ("M-<left>" emacspeak-eww-table-previous-cell)
+     ("M-<right>"  emacspeak-eww-table-next-cell)
+     ("M-." emacspeak-eww-table-speak-cell)
      ("E" eww-view-dom-having-elements)
      ("G" emacspeak-google-command)
      ("I" eww-view-dom-having-id)
@@ -735,7 +748,7 @@ Retain previously set punctuations  mode."
 
 (cl-loop
  for f in
- '(eww eww-reload eww-open-file)
+ '(eww eww-open-in-new-buffer eww-reload eww-open-file)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -842,14 +855,15 @@ Retain previously set punctuations  mode."
 (defadvice eww-follow-link (around emacspeak pre act comp)
   "Respect emacspeak-we-url-executor if set."
   (emacspeak-auditory-icon 'button)
-  (cond
-   ((and (ems-interactive-p)
-         (functionp emacspeak-we-url-executor)
-         (y-or-n-p "Use custom executor? "))
-    (let ((url (get-text-property (point) 'shr-url)))
-      (unless url (error "No URL  under point"))
-      (funcall emacspeak-we-url-executor url)))
-   (t ad-do-it)))
+  (let ((emacspeak-eww-masquerade t))
+    (cond
+     ((and (ems-interactive-p)
+           (functionp emacspeak-we-url-executor)
+           (y-or-n-p "Use custom executor? "))
+      (let ((url (get-text-property (point) 'shr-url)))
+        (unless url (error "No URL  under point"))
+        (funcall emacspeak-we-url-executor url)))
+     (t ad-do-it))))
 
 ;;}}}
 ;;{{{ xslt transform on request:
@@ -870,13 +884,14 @@ Retain previously set punctuations  mode."
 
 (cl-loop
  for  tag in
- '(h1 h2 h3 h4 h5 h6 div                    ; sectioning
-      ul ol dl                     ; Lists
-      li dt dd p                   ; block-level: bullets, paras
-      form blockquote              ; block-level
-      a b it em span               ; in-line
-      br hr                        ; separators
-      th tr table)
+ '(h1 h2 h3 h4 h5 h6 div                ; sectioning
+      math ; mathml 
+      ul ol dl                          ; Lists
+      li dt dd p                        ; block-level: bullets, paras
+      form blockquote                   ; block-level
+      a b it em span                    ; in-line
+      br hr                             ; separators
+      table)
  do
  (eval
   `
@@ -895,6 +910,13 @@ Retain previously set punctuations  mode."
                            (quote ,tag) 'eww-tag)
         (when (memq (quote ,tag) '(h1 h2 h3 h4 h5 h6))
           (put-text-property start end 'h 'eww-tag)))))))
+;;; Handle MathML math element:
+
+(defun shr-tag-math (dom)
+  "Handle Math Nodes from MathML"
+  (shr-ensure-newline)
+      (shr-generic dom)
+      (shr-ensure-newline))
 
 ;;}}}
 ;;{{{ Advice readable
@@ -1005,6 +1027,7 @@ Retain previously set punctuations  mode."
     (form . eww-tag-form)
     (input . eww-tag-input)
     (textarea . eww-tag-textarea)
+    (math . shr-tag-math)
     (meta . eww-tag-meta)
     (button . eww-form-submit)
     (select . eww-tag-select)
@@ -1056,7 +1079,7 @@ attr-value list for use as a DOM filter."
            do
            (setq attr (cl-first pair)
                  value (cl-second pair))
-           (setq found (string= (dom-attr  node attr) value)))
+           (setq found (member value (split-string (dom-attr  node attr)))))
           (when found node)))))
 
 (defun eww-attribute-tester (attr value)
@@ -1439,7 +1462,6 @@ Optional interactive prefix arg `multi' prompts for multiple elements."
 
 (defun eww-display-dom-by-id (id)
   "Display DOM filtered by specified id."
-
   (eww-display-dom-filter-helper #'dom-by-id  id))
 
 (defun eww-display-dom-by-id-list (id-list)
@@ -1687,15 +1709,12 @@ The %s is automatically spoken if there is no user activity."
                (string-prefix-p (emacspeak-google-result-url-prefix) u))
         (kill-new  (emacspeak-google-canonicalize-result-url u))))))
 
-;;}}}
-;;{{{ Masquerade
-
 ;;}}}
 ;;{{{  Google Knowledge Card:
 
 (defun emacspeak-eww-google-knowledge-card ()
   "Show just the knowledge card.
-Warning, this is fragile, and depends on a stable id for the
+Warning, this is fragile, and depends on a stable id/class for the
   knowledge card."
   (interactive)
   (cl-declare (special
@@ -1706,30 +1725,11 @@ Warning, this is fragile, and depends on a stable id for the
     (error "This command is only available in EWW"))
   (unless  emacspeak-google-toolbelt
     (error "This doesn't look like a Google results page."))
-  (let*
-      ((emacspeak-eww-rename-result-buffer nil)
-       (value "rhs_block")
-       (media "rg_meta")
-       (inhibit-read-only t)
-       (dom
-        (eww-dom-remove-if
-         (eww-dom-keep-if
-          (emacspeak-eww-current-dom) (eww-attribute-tester 'id value))
-         (eww-attribute-tester 'class media)))
-       (shr-external-rendering-functions emacspeak-eww-shr-render-functions))
-    (cond
-     (dom
-      (eww-save-history)
-      (erase-buffer)
-      (goto-char (point-min))
-      (shr-insert-document dom)
-      (set-buffer-modified-p nil)
-      (flush-lines "^ *$")
-      (goto-char (point-min))
-      (setq buffer-read-only t)
-      (emacspeak-speak-buffer))
-     (t (message "Knowledge Card not found.")))
-    (emacspeak-auditory-icon 'open-object)))
+  (let  ((dom (emacspeak-eww-current-dom)))
+      (emacspeak-eww-view-helper
+       (dom-html-from-nodes
+        (dom-by-class dom "mod" )
+        (emacspeak-eww-current-url)))))
 
 (define-key emacspeak-google-keymap "k" 'emacspeak-eww-google-knowledge-card)
 (define-key emacspeak-google-keymap "e" 'emacspeak-eww-masquerade)
@@ -1805,16 +1805,12 @@ Warning, this is fragile, and depends on a stable id for the
 ;;}}}
 ;;{{{ Tags At Point:
 
+
+
 (defun emacspeak-eww-tags-at-point ()
   "Display tags at point."
   (interactive)
-  (emacspeak-eww-prepare-eww)
-  (let ((props (text-properties-at (point)))
-        (tags nil))
-    (setq tags
-          (cl-loop
-           for i from 0 to (length props) by 2
-           if (eq 'eww-tag (elt  props (+ 1 i))) collect (elt props i)))
+  (let ((tags (emacspeak-eww-here-tags)))
     (print tags)
     (dtk-speak-list tags)))
 
@@ -1985,8 +1981,9 @@ interactive prefix arg `delete', delete that mark instead."
       (cl-assert  type nil "Mark type is not set.")
       (cl-assert book nil "Book not set.")
       (cond
-       ((emacspeak-eww-jump-to-mark bm) t)
-       (t
+       ((emacspeak-eww-jump-to-mark bm) t) ;;; Found a buffer with
+;;; book open.
+       (t ;;; so we need to first open the book:
         (setq handler
               (cond
                ((eq type 'daisy) #'emacspeak-bookshare-eww)
@@ -2087,7 +2084,6 @@ Warning: Running shell script cbox through this fails mysteriously."
   (emacspeak-eww-smart-tabs-put char url)
   (emacspeak-auditory-icon 'close-object))
 
-
 ;;;###autoload
 (defun emacspeak-eww-smart-tabs (char &optional define)
   "Open URL in EWW keyed by  `char'.
@@ -2095,7 +2091,7 @@ To associate a URL with a char, use this command
 with an interactive prefix arg. "
   (interactive
    (list
-    (read-char-exclusive "Tab:")
+    (read-char-exclusive "EWWTab:")
     current-prefix-arg))
   (cl-declare (special emacspeak-eww-smart-tabs))
   (unless
@@ -2135,13 +2131,103 @@ with an interactive prefix arg. "
     (load-file
      (expand-file-name "smart-eww-tabs" emacspeak-resource-directory))))
 
+;;}}}
+;;{{{Pronunciations:
+
+(emacspeak-pronounce-add-dictionary-entry
+ 'eww-mode
+ (concat " -" emacspeak-pronounce-number-pattern)
+ (cons
+  #'re-search-forward
+  #'(lambda (number)
+      (concat " minus " (substring number 1)))))
+
+;;}}}
+;;{{{Enable Table Browsing:
+;;; Only works for plain tables, not nested tables.
+;;; Point has to be within the displayed table.
+
+(defadvice shr-tag-table-1 (around emacspeak pre act comp)
+  "Cache pointer to table dom as a text property."
+  (let ((table-dom (ad-get-arg 0))
+        (start (point)))
+    ad-do-it
+    (add-text-properties
+     start (point)
+     (list
+      'table-start start
+      'table-end (1-  (point))
+      'table-dom table-dom))
+    ad-return-value))
+
+(defadvice shr-insert-table (around emacspeak pre act comp)
+  "Record table widths."
+  (let ((start (point))
+        (widths (ad-get-arg 1)))
+    ad-do-it
+    (put-text-property start (point) 'table-widths widths)
+    ad-return-value))
+
+(defvar-local emacspeak-eww-table-current-cell 0
+  "Track current table cell to enable table navigation.
+Value is specified as a position in the list of table cells.")
+
+(defsubst emacspeak-eww-table-cells ()
+  "Returns value of table cells as a list."
+  (mapcar
+   #'(lambda (node) (dom-texts node " "))
+   (dom-by-tag (get-text-property (point) 'table-dom) 'td)))
+
+(defun emacspeak-eww-table-speak-cell ()
+  "Speak current cell."
+  (interactive)
+  (cl-declare (special emacspeak-eww-table-current-cell))
+  (dtk-speak (elt (emacspeak-eww-table-cells) emacspeak-eww-table-current-cell)))
+
+(defun emacspeak-eww-table-next-cell (&optional prefix)
+  "Speak next cell after making it current.
+Interactive prefix arg moves to the last cell in the table."
+  (interactive "P")
+  (cl-declare (special emacspeak-eww-table-current-cell))
+  (cl-assert
+   (< (1+ emacspeak-eww-table-current-cell)
+      (length (emacspeak-eww-table-cells)))
+   t "On last cell.")
+  (cond
+   (prefix
+    (setq
+     emacspeak-eww-table-current-cell
+     (1- (length (emacspeak-eww-table-cells))))
+    (goto-char (get-text-property (point) 'table-end)))
+   (t
+    (setq emacspeak-eww-table-current-cell (1+ emacspeak-eww-table-current-cell))
+    (goto-char (next-single-property-change (point) 'display))))
+  (emacspeak-auditory-icon 'left)
+  (dtk-speak (elt (emacspeak-eww-table-cells) emacspeak-eww-table-current-cell)))
+
+(defun emacspeak-eww-table-previous-cell (&optional prefix)
+  "Speak previous cell after making it current.
+With interactive prefix arg, move to the start of the table."
+  (interactive "P")
+  (cl-declare (special emacspeak-eww-table-current-cell))
+  (when  (zerop emacspeak-eww-table-current-cell  ) (error  "On first cell."))
+  (cond
+   (prefix
+    (setq emacspeak-eww-table-current-cell 0)
+    (goto-char (get-text-property (point) 'table-start)))
+   (t
+    (setq emacspeak-eww-table-current-cell (1-
+                                            emacspeak-eww-table-current-cell))
+    (goto-char (previous-single-property-change (point) 'display))))
+  (emacspeak-auditory-icon 'right)
+  (dtk-speak (elt (emacspeak-eww-table-cells) emacspeak-eww-table-current-cell)))
+
 ;;}}}
 (provide 'emacspeak-eww)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
