@@ -386,8 +386,7 @@ This variable is buffer-local.")
 ;;}}}
 ;;{{{  URL Fixup
 
-;;; pattern: http://www.google.com/url?q=http://emacspeak.sourceforge.net/&sa=U&ei=GceWT42_EY_ViALW84nlCQ&ved=0CBIQFjAA&usg=AFQjCNGz91Z7Yz9dPVoKPP6HVGZ0UqFhRA
-;;; prefix: http://www.google.com/url?q=
+;;; prefix: https://www.google.com/url?q=
 ;;; Suffix: &sa=...
 
 (defun emacspeak-google-canonicalize-result-url (url)
@@ -492,6 +491,24 @@ This variable is buffer-local.")
   (let ((emacspeak-websearch-google-options "&tbo=1"))
     (emacspeak-websearch-google emacspeak-google-query)))
 
+(declare-function emacspeak-eww-next-h1 "emacspeak-eww" (&optional speak))
+(declare-function shr-url-at-point "shr" (image-url))
+
+
+(defun emacspeak-google-open-link ()
+  "Open Google link under point."
+  (interactive)
+  (cl-declare (special ems--websearch-google-filter))
+  (let ((url (shr-url-at-point nil)))
+    (cl-assert url t "No link under point.")
+    (add-hook
+     'emacspeak-web-post-process-hook
+     #'(lambda ()
+         (emacspeak-eww-next-h1  'speak)))      
+    (emacspeak-we-extract-by-id-list
+     ems--websearch-google-filter
+     url)))
+
 ;;}}}
 ;;{{{ Sign in, Sign out:
 
@@ -529,6 +546,7 @@ This variable is buffer-local.")
    ("a" emacspeak-google-sign-out)
    ("c" emacspeak-webutils-google-extract-from-cache)
    ("g" emacspeak-websearch-google)
+   ("o" emacspeak-google-open-link)
    ("i" emacspeak-google-what-is-my-ip)
    ("l" emacspeak-webutils-google-who-links-to-this-page)
    ("s" emacspeak-webutils-google-similar-to-this-page)
@@ -631,7 +649,6 @@ Optional interactive prefix arg `lang' specifies  language identifier."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
