@@ -1,5 +1,5 @@
-;;; emacspeak-hideshow.el --- speech-enable hideshow
-;;; $Id: emacspeak-hideshow.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-hideshow.el --- speech-enable hideshow  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable hideshow
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,6 +40,7 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
@@ -54,48 +55,53 @@
 
 (defadvice hs-hide-all (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Hid all blocks.")))
 (defadvice hs-show-all (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Exposed all blocks.")))
 
 (defadvice hs-hide-block (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Hid current block.")))
 
 (defadvice hs-show-block (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Exposed current  block.")))
 
 (defadvice hs-show-region (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Exposed region.")))
 
 (defadvice hs-hide-level (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Hid all blocks below specified level.")))
 
 (defadvice hs-toggle-hiding (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'close-object)
-    (message "Toggled HideShow.")))
+  (when (ems-interactive-p)
+    (cond
+     ((hs-already-hidden-p)
+      (emacspeak-auditory-icon 'close-object)
+      (message "Hid block"))
+     (t
+      (emacspeak-auditory-icon 'open-object)
+      (message "Exposed block")))))
 
 (defadvice hs-hide-initial-comment-block (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Hid initial comment block.")))
 
@@ -106,7 +112,6 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
