@@ -70,6 +70,36 @@
    (info-xref-visited voice-animate-medium)))
 
 ;;}}}
+;;{{{ Module Prefixes 
+
+'(
+  ein:byte
+  ein:debug
+  ein:dev
+  ein:file
+  ein:header
+  ein:ipdb
+  ein:ipynb
+  ein:jupyter
+  ein:jupyterhub
+  ein:log
+  ein:login
+  ein:markdown
+  ein:notebook
+  ein:notebooklist
+  ein:pager
+  ein:process
+  ein:python
+  ein:pytools
+  ein:run
+  ein:shared
+  ein:stop
+  ein:tb
+  ein:traceback
+  ein:version
+  ein:worksheet
+  )
+;;}}}
 ;;{{{ advice
 
 (defcustom  emacspeak-info-select-node-speak-chunk 'node
@@ -257,7 +287,6 @@ node-spec."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
