@@ -167,8 +167,22 @@
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
+
+(defcustom emacspeak-org-table-after-movement-function
+  #'emacspeak-org-table-speak-current-element
+  "The function to call after moving in a table"
+  :type
+  '(choice
+    (const :tag "speak cell contents only" emacspeak-org-table-speak-current-element)
+    (const :tag "speak column header" emacspeak-org-table-speak-column-header)
+    (const :tag "speak row header" emacspeak-org-table-speak-row-header)
+    (const :tag "speak cell contents and column header" emacspeak-org-table-speak-column-header-and-element)
+    (const :tag "speak cell contents and row header" emacspeak-org-table-speak-row-header-and-element)
+    (const :tag "speak column contents and both headers" emacspeak-org-table-speak-both-headers-and-element))
+  :group 'emacspeak-org)
+
 ;;; orgalist-mode defines structured navigators that in turn call org-cycle.
-;;; Removing itneractive check in advice for org-cycle 
+;;; Removing itneractive check in advice for org-cycle
 ;;; to speech enable all such nav commands.
 ;;; Note that org itself produces the folded state via org-unlogged-message
 ;;; Which gets spoken by Emacspeak
@@ -181,11 +195,11 @@
      "Provide auditory feedback."
      (cond
       ((org-at-table-p 'any)
-       (emacspeak-org-table-speak-current-element))
+       (funcall emacspeak-org-table-after-movement-function))
       (t
-;;; org produces relevant feedback via org-unlogged-message (folded, children)
        (let ((dtk-stop-immediately nil))
-         (emacspeak-speak-line)))))))
+         (when (ems-interactive-p)
+           (emacspeak-speak-line))))))))
 
 (defadvice org-overview (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -254,10 +268,10 @@
     ad-do-it
     (if (> (point) prior)
         (tts-with-punctuations
-         'all
-         (if (> (length (emacspeak-get-minibuffer-contents)) 0)
-             (dtk-speak (emacspeak-get-minibuffer-contents))
-           (emacspeak-speak-line)))
+            'all
+          (if (> (length (emacspeak-get-minibuffer-contents)) 0)
+              (dtk-speak (emacspeak-get-minibuffer-contents))
+            (emacspeak-speak-line)))
       (emacspeak-speak-completions-if-available))
     ad-return-value))
 
@@ -431,7 +445,7 @@
   (when (ems-interactive-p)
     (cond
      ((org-at-table-p 'any)
-      (emacspeak-org-table-speak-current-element))
+      (funcall emacspeak-org-table-after-movement-function))
      (t
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object)))))
@@ -591,7 +605,7 @@
  (eval
   `(defadvice ,f  (after emacspeak pre act comp)
      "Provide auditory feedback."
-     (emacspeak-org-table-speak-current-element))))
+     (funcall emacspeak-org-table-after-movement-function))))
 
 ;;}}}
 ;;{{{ Additional table function:
@@ -631,7 +645,7 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
 (defun org-eww-store-link ()
   "Store a link to a EWW buffer."
   (when (eq major-mode 'eww-mode)
-    (org-store-link-props
+    (org-link-store-props
      :type "eww"
      :link   (emacspeak-eww-current-url)
      :url (eww-current-url)
@@ -643,15 +657,15 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
   "Speak prompt intelligently."
   (let ((prompt (ad-get-arg 0))
         (entries (ad-get-arg 2))
-        (first-key (ad-get-arg 4)) 
+        (first-key (ad-get-arg 4))
         (choices nil))
     (setq choices
           (cond
            ((null first-key) entries)
            (t                           ;third  is cl-caddr
             (cl-caddr (assoc first-key entries)))))
-    (dtk-notify-speak 
-     (mapconcat 
+    (dtk-notify-speak
+     (mapconcat
       #'(lambda (e)
           (format "%c: %s\n" (cl-first e) (cl-second e)))
       choices "\n"))
@@ -669,7 +683,7 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
 ;;{{{ Edit Special Advice:
 
 (cl-loop
- for f in 
+ for f in
  '(org-edit-src-exit org-edit-src-abort)
  do
  (eval
@@ -715,7 +729,6 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
