@@ -107,7 +107,11 @@ Values are alists containing string.pronunciation pairs.")
   "Add dictionary entry.
 This adds pronunciation pair
 STRING.PRONUNCIATION to the dictionary.
-Argument KEY specifies a dictionary key e.g. directory, mode etc."
+Argument KEY specifies a dictionary key e.g. directory, mode etc.
+Pronunciation can be a string or a cons-pair.
+If it is a string, that string is the new pronunciation.
+A cons-pair of the form (matcher . func) results  in 
+the match  being passed to the func which returns  the new pronunciation."
   (cl-declare (special emacspeak-pronounce-dictionaries))
   (let* ((dict (emacspeak-pronounce-get-dictionary key))
          (entry (and dict (assoc string dict))))
@@ -377,7 +381,7 @@ Optional argument FILENAME specifies the dictionary file."
   (let ((default (and (mark)
                       (< (count-lines (region-beginning)
                                       (region-end)) 2)
-                      (buffer-substring (region-beginning)
+                      (buffer-substring-no-properties (region-beginning)
                                         (region-end))))
         (emacspeak-pronounce-yank-word-point (point)))
     (setq emacspeak-pronounce-current-buffer (current-buffer))
@@ -390,16 +394,17 @@ Optional argument FILENAME specifies the dictionary file."
        now-map))))
 
 ;;;###autoload
-(defun emacspeak-pronounce-define-local-pronunciation (word pronunciation)
+(defun emacspeak-pronounce-define-local-pronunciation (word pron)
   "Define buffer local pronunciation.
-Argument WORD specifies the word which should be pronounced as specified by PRONUNCIATION."
+Argument `word' specified the word to be pronounced.
+Argument `pron' specifies the new pronunciation. "
   (interactive
    (list
     (emacspeak-pronounce-read-term 'buffer)
     (read-from-minibuffer
      (format "Pronounce as: "))))
   (emacspeak-pronounce-add-buffer-local-dictionary-entry
-   word pronunciation))
+   word pron))
 
 (defun emacspeak-pronounce-get-key ()
   "Collect key from user.
@@ -573,6 +578,9 @@ See http://www.charm.net/~kmarsh/smiley.html. "
                 (string :tag "Pronunciation")))
   :group 'emacspeak-pronounce)
 
+;;}}}
+;;{{{Text Mode Entries:
+
 ;;}}}
 ;;{{{ xml namespace uri's
 
@@ -731,7 +739,10 @@ specified pronunciation dictionary key."
 ;;}}}
 ;;{{{ Helpers: pronouncers
 
-;;{{{ dates
+;;{{{ dates and numbers
+(defvar emacspeak-pronounce-number-pattern
+  "[0-9]+\\.?[0-9]+%?"
+  "Pattern that matches  nnnn.nnnn")
 
 (defvar emacspeak-pronounce-date-mm-dd-yyyy-pattern
   "[0-9]\\{2\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\([0-9]\\{2\\}\\)?"
@@ -835,7 +846,6 @@ specified pronunciation dictionary key."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
