@@ -81,6 +81,10 @@
   (expand-file-name "xsl/" emacspeak-directory)
   "Directory holding XSL transformations.")
 
+;;;###autoload
+(defvar emacspeak-curl-program (executable-find "curl")
+  "Name of CURL executable.")
+
 ;;;###autoload
 (defvar emacspeak-etc-directory
   (expand-file-name  "etc/" emacspeak-directory)
@@ -137,7 +141,6 @@ such as pronunciation dictionaries are stored. ")
       (load-source-file-function  nil))
   (load (expand-file-name "emacspeak.elc" emacspeak-lisp-directory)))
 
-
 (defcustom dtk-startup-hook
   '(emacspeak-tts-startup-hook emacspeak-tts-notify-hook)
   "List of hooks to be run after starting up the speech server.
@@ -152,7 +155,6 @@ hook."
   (cl-declare (special dtk-program))
   (tts-configure-synthesis-setup dtk-program))
 
-
 (defcustom tts-notification-device
   (cl-first (split-string (shell-command-to-string  "aplay -L 2>/dev/null | grep mono")))
   "Virtual ALSA device to use for notifications stream."
