@@ -51,7 +51,7 @@
 
 ;;}}}
 ;;{{{  Required modules
-(eval-when-compile (require 'cl))
+(require 'cl-lib)
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
@@ -192,7 +192,6 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
