@@ -95,7 +95,7 @@ displayed buffers."
      'all
      (dtk-speak (concat description (mapconcat #'identity windows " "))))))
 
-(defalias 'emacspeak-speak-window-layout 'emacspeak-tapestry-describe-tapestry)
+(cl--defalias 'emacspeak-speak-window-layout 'emacspeak-tapestry-describe-tapestry)
 ;;;###autoload
 (defun emacspeak-tapestry-select-window-by-name (buffer-name)
   "Select window by the name of the buffer it displays.
@@ -120,7 +120,6 @@ but quickly switch to a window by name."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
