@@ -1,5 +1,5 @@
-;;; emacspeak-tempo.el --- Speech enable tempo -- template library used for Java and HTML authoring
-;;; $Id: emacspeak-tempo.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-tempo.el --- Speech enable tempo -- template library used for Java and HTML authoring  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extensions for tempo.el (used by html-helper-mode)
 ;;; Keywords: Emacspeak, Spoken Feedback, Template filling, html editing
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -38,14 +38,15 @@
 ;;}}}
 
 ;;{{{  Introduction:
-
+;;; Commentary:
 ;;; tempo.el provides the
 ;;; infrastructure  for building up templates.
 ;;; This is used by html-helper-mode to allow for easy writing of HTML
 ;;; This module extends Emacspeak to provide fluent spoken feedback
-
+;;; Code:
 ;;}}}
 ;;{{{ requires
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -53,29 +54,30 @@
 
 ;;; Prompting in the minibuffer is useful:
 
-(declaim  (special tempo-interactive ))
+(cl-declaim  (special tempo-interactive))
 (setq tempo-interactive t)
-(add-hook 'tempo-insert-string-hook
-          (function (lambda (string)
-                      (dtk-speak string)
-                      string )))
+(add-hook
+ 'tempo-insert-string-hook
+ #'(lambda (string)
+     (dtk-speak string)
+     string))
 
 ;;}}}
 ;;{{{  Advice: 
 
 (defadvice tempo-forward-mark (after emacspeak pre act)
   "Speak the line."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-line)))
 
 (defadvice tempo-backward-mark (after emacspeak pre act)
   "Speak the line."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-line)))
 
 (defadvice html-helper-smart-insert-item  (after emacspeak pre act)
   "Speak the line."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-line)))
 
 ;;}}}
@@ -95,7 +97,6 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
