@@ -67,6 +67,8 @@
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
     (setq emacspeak-tetris-pronunciations-defined t)
+    ;;; add tiles as repeating patterns 
+     (cl-pushnew (format "%c" 0) dtk-cleanup-repeats )
     (mapcar
      #'(lambda (entry)
          (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
@@ -213,7 +215,7 @@ going on. Reduce it as you get better.")
   (cl-declare (special emacspeak-tetris-tick-period))
   emacspeak-tetris-tick-period)
 
-(defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
+(cl--defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
 
 (defvar emacspeak-tetris-width tetris-width
   "*Set this to different values for fun")
@@ -572,7 +574,6 @@ concentration and the game is a good mental challenge. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
