@@ -68,10 +68,8 @@
 (defvar g-scratch-buffer" *g scratch*"
   "Scratch buffer we do authentication work.")
 
-(defcustom g-curl-program "/usr/bin/curl"
-  "Name of CURL executable."
-  :type 'string
-  :group 'g)
+(defvar g-curl-program (executable-find "curl")
+  "Name of CURL executable.")
 
 (defcustom g-atom-view-xsl
   (expand-file-name "atom-view.xsl" g-directory)
@@ -321,11 +319,13 @@ references, poor-man's xpath."
    (set-buffer-multibyte nil) ;return raw binary string
    (buffer-string)))
 
-(defun g-json-get-result(command)
-  "Get command results and return json object read from result
-string."
-  (json-read-from-string
-   (g-get-result command)))
+(defun g-json-get-result (command)
+  "Get command results and return json object read from string."
+  (cond
+   ((fboundp 'json-parse-string)        ; emacs 27.1
+    (json-parse-string (g-get-result command) :object-type 'alist))
+   (t
+    (json-read-from-string (g-get-result command)))))
 
 (defun g-json-from-url (url)
   "Return JSON read from URL."
@@ -472,7 +472,6 @@ Note that in the Curl output, we see lf rather than crlf.")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
