@@ -66,13 +66,12 @@
 ;;; https://developers.google.com/places/
 
 (defcustom gmaps-api-key nil
-  "Places API  key --- goto  https://code.google.com/apis/console to get one."
+  "Maps  API  key --- goto  https://code.google.com/apis/console to get one."
   :type '(choice
           (const :tag "None" nil)
           (string :value ""))
   :group 'gmaps)
 
-
 ;;}}}
 ;;{{{ Address Structure 
 
@@ -293,7 +292,6 @@ Parameter `key' is the API  key."
      ((string= "OK" .status) .routes)
      (t (error "Status %s from Maps" .status)))))
 
-
 ;;}}}
 ;;{{{ Maps UI:
 
@@ -953,7 +951,6 @@ Place details need to have been expanded first."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
