@@ -138,7 +138,6 @@
                    (string :tag "Alsa Device Name"))
   :group 'soundscape)
 
-
 (defcustom soundscape-manager-options
   '("-o" "alsa"
     "-m" "0.3")
@@ -315,6 +314,7 @@ See  \\{soundscape-default-theme} for details."
     ("BlopEchoes"  (elfeed-search-mode))
     ("Bonfire" (calendar-mode diary-mode))
     ("BuddhaLoop" (comint-mode))
+    ("BuddhaLoop" (chess-display-mode))
     ("RandomLoop" nil)
     ("LoopStew" (lisp-interaction-mode))
     ("Cavern" (prog-mode))
@@ -336,6 +336,7 @@ See  \\{soundscape-default-theme} for details."
     ("Still" (text-mode view-mode))
     ("BuddhaLoop" (org-mode))
     ("SurfWaves"  (eww-mode))
+    
     ("TonkSpace" (tabulated-list-mode))
     ("WaterFlow"  (dired-mode))
     )
@@ -370,7 +371,7 @@ Optional interactive prefix arg `prompt-mode' prompts for the mode."
 ;;{{{ Soundscape Remote Control
 
 (defvar soundscape--remote
-  (make-temp-name "/tmp/soundscape")
+  (make-temp-name (expand-file-name  "soundscape" temporary-file-directory))
   "Name of Unix Domain socket used to control Soundscape.")
 
 (defun soundscape-sentinel (proc _state)
@@ -534,7 +535,6 @@ Optional interactive prefix arg `force' skips optimization checks."
   (when (process-live-p soundscape-remote-control)
     (process-send-string soundscape-remote-control "soundscape 0\n")))
 
-
 (defcustom soundscape-idle-delay 0.1
   "Number of seconds of idle time
 before soundscapes are synchronized with current mode."
@@ -632,7 +632,6 @@ This is then saved to soundscape-device for future use."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
