@@ -1,5 +1,4 @@
-;;; voice-setup.el --- Setup voices for voice-lock
-;;; $Id: voice-setup.el 8285 2013-04-03 23:47:57Z tv.raman.tv $
+;;; voice-setup.el --- Setup voices for voice-lock  -*- lexical-binding: t; -*-
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Voice lock mode for Emacspeak
 ;;{{{  LCD Archive entry:
@@ -14,7 +13,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -46,11 +45,11 @@
 ;; spoken in one personality, strings in another, reserved words in another,
 ;; documentation strings in another, and so on.
 ;;
-;; Comments will be spoken in `emacspeak-voice-lock-comment-personality'.
-;; Strings will be spoken in `emacspeak-voice-lock-string-personality'.
+;; Comments will be spoken in `voice-comment-personality'.
+;; Strings will be spoken in `voice-string-personality'.
 ;; Function and variable names (in their defining forms) will be
-;;  spoken in `emacspeak-voice-lock-function-name-personality'.
-;; Reserved words will be spoken in `emacspeak-voice-lock-keyword-personality'.
+;;  spoken in `voice-function-name-personality'.
+;; Reserved words will be spoken in `voice-keyword-personality'.
 ;;
 ;; To make the text you type be voiceified, use M-x voice-lock-mode.
 ;; When this minor mode is on, the voices of the current line are
@@ -86,18 +85,17 @@
 ;;}}}
 ;;{{{ Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (eval-when-compile (require 'easy-mmode))
 (require 'custom)
 (require 'acss-structure)
+(require 'tts)
 (require 'outloud-voices)
-(require 'multispeech-voices)
 (require 'mac-voices)
 (require 'espeak-voices)
 (require 'dectalk-voices)
-
+(require 'emacspeak-sounds)
 ;;}}}
 ;;{{{ customization group
 
@@ -105,37 +103,43 @@
   "Customization group for setting voices."
   :group 'emacspeak)
 
+(declare-function tts-list-voices "dectalk-voices")
+
+(defcustom voice-lock-global-modes t
+  "Modes for which Voice Lock mode is automagically turned on.
+Global Voice Lock mode is controlled by the command `global-voice-lock-mode'.
+If nil, means no modes have Voice Lock mode automatically turned on.
+If t, all modes that support Voice Lock mode have it automatically turned on.
+If a list, it should be a list of `major-mode' symbol names for which Voice Lock
+mode should be automatically turned on.  The sense of the list is negated if it
+begins with `not'.  For example:
+ (c-mode c++-mode)
+means that Voice Lock mode is turned on for buffers in C and C++ modes only."
+  :type '(choice (const :tag "none" nil)
+                 (const :tag "all" t)
+                 (set :menu-tag "mode specific" :tag "modes"
+                      :value (not)
+                      (const :tag "Except" not)
+                      (repeat :inline t (symbol :tag "mode"))))
+  :group 'voice-lock)
+
 ;;}}}
 ;;{{{  helper for voice custom items:
+(unless (fboundp 'tts-list-voices)
+  (fset 'tts-list-voices #'dectalk-list-voices))
 
-(defalias 'tts-list-voices 'dectalk-list-voices)
 (defun voice-setup-custom-menu ()
   "Return a choice widget used in selecting voices."
-  (let ((v (tts-list-voices))
-        (menu nil))
-    (setq menu
-          (mapcar
-           #'(lambda (voice)
-               (list 'const voice))
-           v))
-    (setq menu
-          (cons
-           (list 'symbol :tag "Other")
-           menu))
-    (cons 'choice menu)))
+  `(choice
+    (symbol :tag "Other")
+    ,@(mapcar 
+       #'(lambda (voice)(list 'const voice))
+       (tts-list-voices))))
 
 (defun voice-setup-read-personality (&optional prompt)
   "Read name of a pre-defined personality using completion."
-  (let ((table (mapcar
-                #'(lambda (v)
-                    (cons
-                     (format "%s" v)
-                     (format "%s" v)))
-                (tts-list-voices))))
-    (read
-     (completing-read
-      (or prompt "Personality: ")
-      table))))
+  (read (completing-read (or prompt "Personality: ")
+                         (tts-list-voices))))
 
 ;;}}}
 ;;{{{ map faces to voices
@@ -143,21 +147,21 @@
 (defvar voice-setup-face-voice-table (make-hash-table)
   "Hash table holding face to voice mapping.")
 
-(defsubst voice-setup-set-voice-for-face (face voice)
+(defun voice-setup-set-voice-for-face (face voice)
   "Map face --a symbol-- to relevant voice."
-  (declare (special  voice-setup-face-voice-table))
+  (cl-declare (special  voice-setup-face-voice-table))
   (setf (gethash face voice-setup-face-voice-table) voice))
 
-(defsubst voice-setup-get-voice-for-face (face)
+(defun voice-setup-get-voice-for-face (face)
   "Map face --a symbol-- to relevant voice."
-  (declare (special  voice-setup-face-voice-table))
+  (cl-declare (special  voice-setup-face-voice-table))
   (gethash face voice-setup-face-voice-table))
 
 (defun voice-setup-show-rogue-faces ()
   "Return list of voices that map to non-existent faces."
-  (declare (special voice-setup-face-voice-table))
-  (loop for f being the hash-keys of voice-setup-face-voice-table
-        unless (facep f) collect f))
+  (cl-declare (special voice-setup-face-voice-table))
+  (cl-loop for f being the hash-keys of voice-setup-face-voice-table
+           unless (facep f) collect f))
 
 ;;}}}
 ;;{{{ special form def-voice-font
@@ -168,6 +172,7 @@
 
 (defmacro  def-voice-font (personality voice face doc &rest args)
   "Define personality and map it to specified face."
+  (declare (indent 1) (debug t))
   (let ((documentation
          (concat
           doc
@@ -185,7 +190,7 @@
                    (let ((observing  (get sym 'observing)))
                      (when (and (symbolp sym)
                                 (symbolp observing))
-                       (remprop observing sym))
+                       (cl-remprop observing sym))
                      (set-default sym val)))
            ,@args))
 ;;; other actions performed at define time
@@ -197,20 +202,25 @@
        (when (symbolp ',voice)
          (put  ',voice ',personality t)))))
 
-(defsubst voice-setup-name-personality (face-name)
+(defun voice-setup-name-personality (face-name)
   "Compute personality name to use."
   (let ((name nil))
     (setq name
           (or
            (replace-regexp-in-string "face$" "personality" face-name)
            face-name))
+    (setq name
+          (or
+           (replace-regexp-in-string "font-lock" "voice" name
+                                     (replace-regexp-in-string "font" "voice" name))
+           name))
     (setq name
           (or
            (replace-regexp-in-string "font" "voice" name)
            name))
     (when (string-equal name face-name)
-      (setq name (format "%s-voice" name)))
-    (concat "emacspeak-" name)))
+      (setq name (format "voice-%s" name)))
+    name))
 
 (defun voice-setup-map-face (face voice)
   "Invoke def-voice-font with appropriately generated personality name."
@@ -220,11 +230,12 @@
     (eval
      `(def-voice-font ,personality ,voice  ',face  ,doc))))
 
-(defun voice-setup-add-map (fv-alist )
+(defun voice-setup-add-map (fv-alist)
   "Sets up face to voice mapping given in fv-alist."
-  (loop for fv in fv-alist
-        do
-        (voice-setup-map-face (first fv) (second fv))))
+  (cl-loop
+   for fv in fv-alist
+   do
+   (voice-setup-map-face (cl-first fv) (cl-second fv))))
 
 ;;}}}
 ;;{{{  special form defvoice
@@ -233,9 +244,9 @@
   "Maps personality names to ACSS  settings.
 Keys are personality names.")
 
-(defsubst voice-setup-personality-from-style (style-list)
+(defun voice-setup-personality-from-style (style-list)
   "Define a personality given a list of speech style settings."
-  (declare (special voice-setup-personality-table))
+  (cl-declare (special voice-setup-personality-table))
   (let ((voice
          (acss-personality-from-speech-style
           (make-acss
@@ -248,22 +259,22 @@ Keys are personality names.")
     (puthash  voice style-list voice-setup-personality-table)
     voice))
 
-(defsubst voice-setup-observing-personalities  (voice-name)
+(defun voice-setup-observing-personalities  (voice-name)
   "Return a list of personalities that are `observing' VOICE-NAME.
 Observing personalities are automatically updated when settings for
 VOICE-NAME are  changed."
   (let* ((plist (symbol-plist voice-name))
          (l (1- (length plist))))
-    (loop for i from 0 to l by 2
-          collect (nth i plist))))
+    (cl-loop for i from 0 to l by 2
+             collect (nth i plist))))
 
 (defun voice-setup-update-personalities (personality)
   "Update  personalities  that use this voice to  new setting."
   (let ((value (symbol-value personality))
         (observers (voice-setup-observing-personalities personality)))
-    (loop for o in observers
-          do                            ;o is already quoted
-          (set o value))))
+    (cl-loop for o in observers
+             do                            ;o is already quoted
+             (set o value))))
 
 ;;; note that for now we dont use  gain settings
 
@@ -272,14 +283,15 @@ VOICE-NAME are  changed."
 (list paul 5 5 5 5 'all) which defines a standard male voice
 that speaks `all' punctuations.  Once
 defined, the newly declared personality can be customized by calling
-command \\[customize-variable] on <personality>-settings.. "
+command \\[customize-variable] on <personality>-settings. "
+  (declare (indent 1) (debug t))
   `(progn
      (defvar  ,personality
        (voice-setup-personality-from-style ,settings)
        ,(concat
          doc
          (format "Customize this overlay via %s-settings."
-                 personality )))
+                 personality)))
      (defcustom ,(intern (format "%s-settings"  personality))
        ,settings
        ,doc
@@ -311,7 +323,7 @@ command \\[customize-variable] on <personality>-settings.. "
        '(lambda  (sym val)
           (let ((voice-name (voice-setup-personality-from-style val)))
             (setq ,personality voice-name)
-;;; update all observers                ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ;
+;;; update all observers
             (voice-setup-update-personalities ',personality)
             (set-default sym val))))))
 
@@ -321,12 +333,10 @@ command \\[customize-variable] on <personality>-settings.. "
 ;;; these voices are device independent 
 
 (defvoice  voice-punctuations-all (list nil nil nil nil  nil 'all)
-  "Turns current voice into one that  speaks all
-punctuations.")
+  "Turns current voice into one that  speaks all punctuations.")
 
 (defvoice  voice-punctuations-some (list nil nil nil nil  nil 'some)
-  "Turns current voice into one that  speaks some
-punctuations.")
+  "Turns current voice into one that  speaks some punctuations.")
 
 (defvoice  voice-punctuations-none (list nil nil nil nil  nil "none")
   "Turns current voice into one that  speaks no punctuations.")
@@ -337,52 +347,55 @@ punctuations.")
 (defvoice  voice-monotone-medium (list nil nil 2 2  nil 'all)
   "Turns current voice into a medium monotone.")
 
-(defvoice voice-animate (list nil 7 7 6)
+(defvoice  voice-monotone-light (list nil nil 4 4   nil 'all)
+  "Turns current voice into a light monotone.")
+
+(defvoice voice-animate-extra (list nil 8 8 6)
+  "Adds extra animation  to current voice.")
+
+(defvoice voice-animate (list nil 7 7 4)
   "Animates current voice.")
 
-(defvoice voice-animate-medium (list nil 6 6  5)
+(defvoice voice-animate-medium (list nil 6 6  3)
   "Adds medium animation  current voice.")
 
-(defvoice voice-animate-extra (list nil 8 8 7 )
-  "Adds extra animation  current voice.")
-
-(defvoice voice-smoothen (list nil nil nil 3 4)
-  "Smoothen current voice.")
-
-(defvoice voice-smoothen-extra (list nil nil nil 3 2)
+(defvoice voice-smoothen-extra (list nil nil nil 4 5)
   "Extra smoothen current voice.")
 
-(defvoice voice-smoothen-medium (list nil nil nil 3 3)
+(defvoice voice-smoothen-medium (list nil nil nil 3 4)
   "Add medium smoothen current voice.")
 
+(defvoice voice-smoothen (list nil nil  2 2)
+  "Smoothen current voice.")
+
 (defvoice voice-brighten-medium (list nil nil nil 5 6)
-  "Brighten current voice.")
+  "Brighten  (medium) current voice.")
 
 (defvoice voice-brighten (list nil nil nil 6 7)
   "Brighten current voice.")
 
-(defvoice voice-brighten-extra (list nil nil nil 7 8 )
+(defvoice voice-brighten-extra (list nil nil nil 7 8)
   "Extra brighten current voice.")
 
-(defvoice voice-bolden (list nil 1 6 6  nil)
+(defvoice voice-bolden (list nil 3 6 6  6)
   "Bolden current voice.")
 
-(defvoice voice-bolden-extra (list nil 0 6 7 8 )
-  "Extra bolden current voice.")
-
-(defvoice voice-bolden-medium (list nil 3 6 6  nil)
+(defvoice voice-bolden-medium (list nil 2 6 7  7)
   "Add medium bolden current voice.")
 
-(defvoice voice-lighten (list nil 7 7  1  nil)
+(defvoice voice-bolden-extra (list nil 1 6 7 8)
+  "Extra bolden current voice.")
+
+(defvoice voice-lighten (list nil 6 6 2   nil)
   "Lighten current voice.")
 
-(defvoice voice-lighten-medium (list nil 6 6 3  nil)
-  "Add medium lighten current voice.")
+(defvoice voice-lighten-medium (list nil 7 7 3  nil)
+  "Add medium lightness to  current voice.")
 
-(defvoice voice-lighten-extra (list nil 9 8 7   9)
-  "Add extra lighten current voice.")
+(defvoice voice-lighten-extra (list nil 9 8 7   nil)
+  "Add extra lightness to  current voice.")
 
-(defvoice voice-bolden-and-animate (list nil 8 8 8 8 )
+(defvoice voice-bolden-and-animate (list nil 3 8 8 8)
   "Bolden and animate  current voice.")
 
 (defvoice voice-womanize-1 (list 'betty 5 nil nil nil nil)
@@ -391,7 +404,7 @@ punctuations.")
 ;;}}}
 ;;{{{  indentation and annotation
 
-(defvoice voice-indent (list nil nil 3 1 3 )
+(defvoice voice-indent (list nil nil 3 1 3)
   "Indicate indentation .")
 
 (defvoice voice-annotate (list nil nil 4 0 4)
@@ -422,12 +435,15 @@ punctuations.")
 
 (voice-setup-add-map
  '(
+   (shr-link voice-bolden)
    (bold voice-bolden)
-   (variable-pitch voice-animate)
    (bold-italic voice-bolden-and-animate)
-   (button voice-bolden)
-   (link voice-bolden)
-   (warning voice-bolden-and-animate)
+   (button voice-bolden-medium)
+   (link voice-bolden-medium)
+   (link-visited voice-bolden)
+   (success voice-brighten-extra)
+   (error voice-animate)
+   (warning voice-smoothen)
    (fixed-pitch voice-monotone)
    (font-lock-builtin-face voice-bolden)
    (font-lock-comment-face voice-monotone)
@@ -441,17 +457,23 @@ punctuations.")
    (font-lock-keyword-face voice-animate-extra)
    (font-lock-preprocessor-face voice-monotone-medium)
    (shadow voice-monotone-medium)
+   (file-name-shadow voice-monotone-medium)
+   (fringe voice-monotone-medium)
+   (secondary-selection voice-lighten-medium)
    (font-lock-string-face voice-lighten-extra)
    (font-lock-type-face voice-smoothen)
-   (font-lock-variable-name-face voice-bolden)
+   (font-lock-variable-name-face voice-bolden-extra)
    (font-lock-warning-face voice-bolden-and-animate)
    (help-argument-name voice-smoothen)
+   (query-replace voice-bolden)
+   (match voice-lighten)
    (isearch voice-bolden)
+   (isearch-fail voice-monotone)
    (highlight voice-animate)
    (italic voice-animate)
    (match voice-animate)
    (region voice-brighten)
-   (underline voice-lighten-medium)
+   (underline voice-lighten-extra)
    ))
 
 ;;}}}
@@ -461,9 +483,9 @@ punctuations.")
 (define-minor-mode voice-lock-mode
   "Toggle voice lock mode."
   t nil nil
-  (when (ems-interactive-p )
+  (when (called-interactively-p 'interactive)
     (let ((state (if voice-lock-mode 'on 'off)))
-      (when (ems-interactive-p )
+      (when (ems-interactive-p)
         (emacspeak-auditory-icon state)))))
 
 ;;;###autoload
@@ -485,25 +507,24 @@ punctuations.")
   (if voice-lock-mode
       (turn-off-voice-lock)
     (turn-on-voice-lock))
-  (when (ems-interactive-p )
-    (let ((state (if voice-lock-mode 'on 'off)))
-      (when (ems-interactive-p )
-        (emacspeak-auditory-icon state)))))
+  (when (called-interactively-p 'interactive)
+    (message "Turned %s voice lock mode in buffer. " 
+             (if voice-lock-mode " on " " off "))
+    (emacspeak-auditory-icon (if voice-lock-mode 'on 'off))))
 
 ;;;###autoload
 (defvar global-voice-lock-mode t
   "Global value of voice-lock-mode.")
 
-(when (string-match "24" emacs-version)
-  (define-globalized-minor-mode global-voice-lock-mode
-    voice-lock-mode turn-on-voice-lock
-    :initialize 'custom-initialize-delay
-    :init-value (not (or noninteractive emacs-basic-display))
-    :group 'voice-lock
-    :version "24.1"))
+(define-globalized-minor-mode global-voice-lock-mode
+  voice-lock-mode turn-on-voice-lock
+  :initialize 'custom-initialize-delay
+  :init-value (not (or noninteractive emacs-basic-display))
+  :group 'voice-lock
+  :version "24.1")
 
 ;; Install ourselves:
-(declaim (special text-property-default-nonsticky))
+(cl-declaim (special text-property-default-nonsticky))
 (unless (assq 'personality text-property-default-nonsticky)
   (push  (cons 'personality t) text-property-default-nonsticky))
 
@@ -525,8 +546,7 @@ Sample text to use comes from variable
   `voice-setup-sample-text'. "
   (interactive (list (and current-prefix-arg
                           (read-string "List faces matching regexp: "))))
-  (declare (special voice-setup-sample-text
-                    list-faces-sample-text))
+  (cl-declare (special voice-setup-sample-text))
   (let ((list-faces-sample-text voice-setup-sample-text))
     (list-faces-display pattern)
     (message "Displayed voice-face mappings in other window.")))
@@ -547,21 +567,80 @@ then the original face->personality mapping is restored.  In
 either case, the buffer is refontified to have the new mapping
 take effect."
   (interactive)
-  (declare (special voice-setup-buffer-face-voice-table))
-  (let* ((personality (get-text-property (point) 'personality))
+  (cl-declare (special voice-setup-buffer-face-voice-table))
+  (let* ((personality  (dtk-get-style))
          (face (get-text-property (point) 'face))
          (orig (gethash face voice-setup-buffer-face-voice-table)))
     (cond
+     ((null personality) (message "No personality here."))
      ((eq personality  'inaudible)
       (voice-setup-set-voice-for-face face  orig)
+      (message "Made personality %s audible." orig)
       (emacspeak-auditory-icon 'open-object))    
      (t (voice-setup-set-voice-for-face face 'inaudible)
         (setf
          (gethash face voice-setup-buffer-face-voice-table)
          personality)
+        (message "Silenced personality %s" personality)
         (emacspeak-auditory-icon 'close-object)))
-    (when (buffer-file-name)
-      (normal-mode))))
+    (when (buffer-file-name) (normal-mode))))
+
+;;}}}
+;;{{{ Helper: voice-setup-defined-voices 
+
+(defun voice-setup-defined-voices ()
+  "Return list of voices defined via defvoice."
+  (let ((result nil))
+    (mapatoms
+     #'(lambda (s)
+         (when  
+             (and
+              (string-match "^voice-"  (symbol-name s))
+              (boundp s)
+              (symbolp (symbol-value s))
+              (string-match  "^acss-" (symbol-name  (symbol-value s))))
+           (push s result))))
+    result))
+
+;;}}}
+;;{{{ describe-voice at point:
+
+(defun voice-setup-describe-personality(personality)
+  "Describe specified voice --- analogous to \\[describe-face].
+When called interactively, `personality' defaults to first personality at point.
+If there are multiple personalities at point,
+these are available via minibuffer history."
+  (interactive
+   (list
+    (let* ((v (dtk-get-style)))
+      (setq v
+            (if (listp v)
+                (mapcar #'symbol-name v)
+              (symbol-name v)))
+      (when (listp v) (setq v (cl-first v)))
+      (read-from-minibuffer
+       "Personality: "
+       nil nil 'read nil  v))))
+  (let ((voice (get personality 'observing))
+        (settings nil)
+        (n '(family average-pitch pitch-range stress richness punctuations))
+        (values nil))
+    (when voice (setq settings (intern (format "%s-settings" voice))))
+    (cond
+     ((symbol-value settings) ;;; globally bound, display it
+      (setq values (symbol-value settings))
+      (with-help-window (help-buffer)
+        (with-current-buffer standard-output
+          (insert (format "Personality: %s\tVoice:%s\n\n" personality voice))
+          (put-text-property (point-min) (point)
+                             'personality personality)
+          (cl-loop
+           for i from 0 to (1- (length n))do
+           (insert (format "%s: %s\n"
+                           (elt n i) (elt values i))))))
+      (when (called-interactively-p 'interactive)
+        (emacspeak-speak-help)))
+     (t (message "%s doesn't look like a valid personality." personality)))))
 
 ;;}}}
 (provide 'voice-setup)
@@ -569,7 +648,6 @@ take effect."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
